##
## wod_4biasedhist: Observation influence estimation by bootstrap , returns the matrix with all measures
##
##
## 

## Function wod_4biasedhist
##
##                  performance metric : concordance index

##  Arguments:      data  : SurvivalDataSet object
##                  nruns  : number of runs of the bootstrap
##                

wod_4biasedhist_k_p <-  function( obs_index, surv.object , covariate.data,  nruns   , m) {
  
  actual_data <- cbind( covariate.data , surv.object[,1],  surv.object[,2] )
  
  time_index   <- ncol(actual_data) - 1
  status_index <- ncol(actual_data)  
  
  
  data_length  <- nrow(actual_data)
  
  concs_vector  <- rep(x = 0, nruns  )
  
  ## calculate the baseline concordance, according to the baseline (all observations)
  #
  cox_object <- coxph( Surv(actual_data[,time_index], as.integer(actual_data[,status_index]) ) ~ .   , data = actual_data[,-c(time_index,status_index)] )
  baseline_concordance <- cox_object$concordance[1]/(cox_object$concordance[1] + cox_object$concordance[2] )   
  
  cat("baseline:" , baseline_concordance )
  
    concordance_sum <- 0
    
    for ( i in 1:nruns ){
      
      boot_datax <- getBootstrapBiased_k(data = actual_data,obs_index = obs_index , k = m)
      actual_conc <- coxph.call(boot_data = boot_datax,time_index = time_index,status_index = status_index)
      if (is.null(actual_conc)) {
        for( ix in 1:10) {
          cat('Error: ', ix)
          boot_datax <- getBootstrapBiased_k(data = actual_data,obs_index = obs_index , k = m)
          actual_conc <- coxph.call(boot_data = boot_datax,time_index = time_index,status_index = status_index)
          if (!is.null(actual_conc)) {
            break
          }
        }
      }
      if (is.null(actual_conc)) {
        next
      }
      
      ##
      ##scores_predicted <- predict(cox_object,actual_data[,-c(time_index,status_index)] )
      ##conc      <- survConcordance(Surv(time = actual_data[,time_index],actual_data[,status_index] ) ~ scores_predicted )
      ##actual_conc <- conc$concordance
      ###
    
      concordance_run <- actual_conc - baseline_concordance
      concs_vector[i] <- concordance_run 
    }
    
  
  return(concs_vector)
  
}